==> auxygen-2017.4.26.tar.gz: auxygen-2017.4.26/auxygen/gui/ui/ui_wblower.py <==
# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WBlower(object):
    def setupUi(self, WBlower):
        WBlower.setObjectName("WBlower")
        WBlower.resize(615, 492)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/blower"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        WBlower.setWindowIcon(icon)
        WBlower.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.verticalLayout = QtWidgets.QVBoxLayout(WBlower)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(WBlower)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtWidgets.QLabel(self.tab)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.labelTemp = QtWidgets.QLabel(self.tab)
        font = QtGui.QFont()
        font.setFamily("Ubuntu Mono")
        font.setPointSize(40)
        self.labelTemp.setFont(font)
        self.labelTemp.setObjectName("labelTemp")
        self.horizontalLayout_2.addWidget(self.labelTemp)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_10 = QtWidgets.QLabel(self.tab)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_7.addWidget(self.label_10)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.labelCurrent = QtWidgets.QLabel(self.tab)
        font = QtGui.QFont()
        font.setFamily("Ubuntu Mono")
        font.setPointSize(20)
        self.labelCurrent.setFont(font)
        self.labelCurrent.setObjectName("labelCurrent")
        self.horizontalLayout_7.addWidget(self.labelCurrent)
        self.verticalLayout_2.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_2 = QtWidgets.QLabel(self.tab)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_4.addWidget(self.label_2)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem2)
        self.spinTarget = QtWidgets.QDoubleSpinBox(self.tab)
        self.spinTarget.setSuffix("")
        self.spinTarget.setDecimals(1)
        self.spinTarget.setMinimum(25.0)
        self.spinTarget.setMaximum(1000.0)
        self.spinTarget.setObjectName("spinTarget")
        self.horizontalLayout_4.addWidget(self.spinTarget)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_3 = QtWidgets.QLabel(self.tab)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_3.addWidget(self.label_3)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem3)
        self.spinRamp = QtWidgets.QDoubleSpinBox(self.tab)
        self.spinRamp.setSuffix("")
        self.spinRamp.setDecimals(1)
        self.spinRamp.setMinimum(0.0)
        self.spinRamp.setMaximum(1000.0)
        self.spinRamp.setObjectName("spinRamp")
        self.horizontalLayout_3.addWidget(self.spinRamp)
        self.verticalLayout_2.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.buttonRun = QtWidgets.QPushButton(self.tab)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/run"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.buttonRun.setIcon(icon1)
        self.buttonRun.setObjectName("buttonRun")
        self.horizontalLayout_5.addWidget(self.buttonRun)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem4)
        self.buttonToSeq = QtWidgets.QPushButton(self.tab)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/macro"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.buttonToSeq.setIcon(icon2)
        self.buttonToSeq.setObjectName("buttonToSeq")
        self.horizontalLayout_5.addWidget(self.buttonToSeq)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.tab_2)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.plotView = PlotWidget(self.tab_2)
        self.plotView.setObjectName("plotView")
        self.verticalLayout_3.addWidget(self.plotView)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem5)
        self.buttonStartPlot = QtWidgets.QPushButton(self.tab_2)
        self.buttonStartPlot.setIcon(icon1)
        self.buttonStartPlot.setObjectName("buttonStartPlot")
        self.horizontalLayout_6.addWidget(self.buttonStartPlot)
        self.buttonClearPlot = QtWidgets.QPushButton(self.tab_2)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/clear"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.buttonClearPlot.setIcon(icon3)
        self.buttonClearPlot.setObjectName("buttonClearPlot")
        self.horizontalLayout_6.addWidget(self.buttonClearPlot)
        self.verticalLayout_3.addLayout(self.horizontalLayout_6)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.formLayout = QtWidgets.QFormLayout(self.tab_3)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.label_4 = QtWidgets.QLabel(self.tab_3)
        self.label_4.setObjectName("label_4")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.editHost = QtWidgets.QLineEdit(self.tab_3)
        self.editHost.setObjectName("editHost")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.editHost)
        self.label_5 = QtWidgets.QLabel(self.tab_3)
        self.label_5.setObjectName("label_5")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.editSession = QtWidgets.QLineEdit(self.tab_3)
        self.editSession.setObjectName("editSession")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.editSession)
        self.label_6 = QtWidgets.QLabel(self.tab_3)
        self.label_6.setObjectName("label_6")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_6)
        self.editMotor = QtWidgets.QLineEdit(self.tab_3)
        self.editMotor.setObjectName("editMotor")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.editMotor)
        self.label_7 = QtWidgets.QLabel(self.tab_3)
        self.label_7.setObjectName("label_7")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_7)
        self.editCounter = QtWidgets.QLineEdit(self.tab_3)
        self.editCounter.setObjectName("editCounter")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.editCounter)
        self.editRamp = QtWidgets.QLineEdit(self.tab_3)
        self.editRamp.setObjectName("editRamp")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.editRamp)
        spacerItem6 = QtWidgets.QSpacerItem(20, 119, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.formLayout.setItem(10, QtWidgets.QFormLayout.FieldRole, spacerItem6)
        self.label_8 = QtWidgets.QLabel(self.tab_3)
        self.label_8.setObjectName("label_8")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.editError = QtWidgets.QLineEdit(self.tab_3)
        self.editError.setObjectName("editError")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.editError)
        self.label_9 = QtWidgets.QLabel(self.tab_3)
        self.label_9.setObjectName("label_9")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.label_9)
        self.editComTimout = QtWidgets.QLineEdit(self.tab_3)
        self.editComTimout.setObjectName("editComTimout")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.editComTimout)
        self.label_11 = QtWidgets.QLabel(self.tab_3)
        self.label_11.setObjectName("label_11")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.label_11)
        self.tabWidget.addTab(self.tab_3, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.buttonConnect = QtWidgets.QPushButton(WBlower)
        self.buttonConnect.setObjectName("buttonConnect")
        self.horizontalLayout.addWidget(self.buttonConnect)
        self.buttonDisconnect = QtWidgets.QPushButton(WBlower)
        self.buttonDisconnect.setObjectName("buttonDisconnect")
        self.horizontalLayout.addWidget(self.buttonDisconnect)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem7)
        self.buttonClose = QtWidgets.QPushButton(WBlower)
        self.buttonClose.setObjectName("buttonClose")
        self.horizontalLayout.addWidget(self.buttonClose)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(WBlower)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(WBlower)

    def retranslateUi(self, WBlower):
        _translate = QtCore.QCoreApplication.translate
        WBlower.setWindowTitle(_translate("WBlower", "Blower status"))
        self.label.setText(_translate("WBlower", "Temperature"))
        self.labelTemp.setText(_translate("WBlower", "<html><head/><body><p>0 &deg;C</p></body></html>"))
        self.label_10.setText(_translate("WBlower", "Current target and ramp"))
        self.labelCurrent.setText(_translate("WBlower", "<html><head/><body><p>0 &deg;C</p></body></html>"))
        self.label_2.setText(_translate("WBlower", "Target temperature"))
        self.label_3.setText(_translate("WBlower", "Temperature ramp (deg/min)"))
        self.buttonRun.setText(_translate("WBlower", "Run"))
        self.buttonToSeq.setText(_translate("WBlower", "To Sequence"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("WBlower", "Control"))
        self.buttonStartPlot.setText(_translate("WBlower", "Start"))
        self.buttonClearPlot.setText(_translate("WBlower", "Clear"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("WBlower", "Plot"))
        self.label_4.setText(_translate("WBlower", "Host"))
        self.label_5.setText(_translate("WBlower", "Session"))
        self.label_6.setText(_translate("WBlower", "Motor"))
        self.label_7.setText(_translate("WBlower", "Counter"))
        self.label_8.setText(_translate("WBlower", "Ramp"))
        self.label_9.setText(_translate("WBlower", "Error"))
        self.label_11.setText(_translate("WBlower", "Communication timeout"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("WBlower", "Settings"))
        self.buttonConnect.setText(_translate("WBlower", "Connect"))
        self.buttonDisconnect.setText(_translate("WBlower", "Disconnect"))
        self.buttonClose.setText(_translate("WBlower", "Close"))

from pyqtgraph import PlotWidget
from . import resources_rc

==> auxygen-2017.7.27.tar.gz: auxygen-2017.7.27/auxygen/gui/ui/ui_wblower.py <==
# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WBlower(object):
    def setupUi(self, WBlower):
        WBlower.setObjectName("WBlower")
        WBlower.resize(624, 493)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/blower"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        WBlower.setWindowIcon(icon)
        WBlower.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.verticalLayout = QtWidgets.QVBoxLayout(WBlower)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(WBlower)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtWidgets.QLabel(self.tab)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.labelTemp = QtWidgets.QLabel(self.tab)
        font = QtGui.QFont()
        font.setFamily("Ubuntu Mono")
        font.setPointSize(40)
        self.labelTemp.setFont(font)
        self.labelTemp.setObjectName("labelTemp")
        self.horizontalLayout_2.addWidget(self.labelTemp)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_10 = QtWidgets.QLabel(self.tab)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_7.addWidget(self.label_10)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.labelCurrent = QtWidgets.QLabel(self.tab)
        font = QtGui.QFont()
        font.setFamily("Ubuntu Mono")
        font.setPointSize(20)
        self.labelCurrent.setFont(font)
        self.labelCurrent.setObjectName("labelCurrent")
        self.horizontalLayout_7.addWidget(self.labelCurrent)
        self.verticalLayout_2.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_2 = QtWidgets.QLabel(self.tab)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_4.addWidget(self.label_2)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem2)
        self.spinTarget = QtWidgets.QDoubleSpinBox(self.tab)
        self.spinTarget.setSuffix("")
        self.spinTarget.setDecimals(1)
        self.spinTarget.setMinimum(25.0)
        self.spinTarget.setMaximum(1000.0)
        self.spinTarget.setObjectName("spinTarget")
        self.horizontalLayout_4.addWidget(self.spinTarget)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_3 = QtWidgets.QLabel(self.tab)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_3.addWidget(self.label_3)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem3)
        self.spinRamp = QtWidgets.QDoubleSpinBox(self.tab)
        self.spinRamp.setSuffix("")
        self.spinRamp.setDecimals(1)
        self.spinRamp.setMinimum(0.0)
        self.spinRamp.setMaximum(1000.0)
        self.spinRamp.setObjectName("spinRamp")
        self.horizontalLayout_3.addWidget(self.spinRamp)
        self.verticalLayout_2.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.buttonRun = QtWidgets.QPushButton(self.tab)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/run"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.buttonRun.setIcon(icon1)
        self.buttonRun.setObjectName("buttonRun")
        self.horizontalLayout_5.addWidget(self.buttonRun)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem4)
        self.buttonToSeq = QtWidgets.QPushButton(self.tab)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/macro"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.buttonToSeq.setIcon(icon2)
        self.buttonToSeq.setObjectName("buttonToSeq")
        self.horizontalLayout_5.addWidget(self.buttonToSeq)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.tab_2)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.plotView = PlotWidget(self.tab_2)
        self.plotView.setObjectName("plotView")
        self.verticalLayout_3.addWidget(self.plotView)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem5)
        self.buttonStartPlot = QtWidgets.QPushButton(self.tab_2)
        self.buttonStartPlot.setIcon(icon1)
        self.buttonStartPlot.setObjectName("buttonStartPlot")
        self.horizontalLayout_6.addWidget(self.buttonStartPlot)
        self.buttonClearPlot = QtWidgets.QPushButton(self.tab_2)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/clear"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.buttonClearPlot.setIcon(icon3)
        self.buttonClearPlot.setObjectName("buttonClearPlot")
        self.horizontalLayout_6.addWidget(self.buttonClearPlot)
        self.verticalLayout_3.addLayout(self.horizontalLayout_6)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.formLayout = QtWidgets.QFormLayout(self.tab_3)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.label_4 = QtWidgets.QLabel(self.tab_3)
        self.label_4.setObjectName("label_4")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.editHost = QtWidgets.QLineEdit(self.tab_3)
        self.editHost.setObjectName("editHost")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.editHost)
        self.label_5 = QtWidgets.QLabel(self.tab_3)
        self.label_5.setObjectName("label_5")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.editSession = QtWidgets.QLineEdit(self.tab_3)
        self.editSession.setObjectName("editSession")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.editSession)
        self.label_7 = QtWidgets.QLabel(self.tab_3)
        self.label_7.setObjectName("label_7")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_7)
        self.editCounter = QtWidgets.QLineEdit(self.tab_3)
        self.editCounter.setObjectName("editCounter")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.editCounter)
        self.label_8 = QtWidgets.QLabel(self.tab_3)
        self.label_8.setObjectName("label_8")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.editRamp = QtWidgets.QLineEdit(self.tab_3)
        self.editRamp.setObjectName("editRamp")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.editRamp)
        self.label_9 = QtWidgets.QLabel(self.tab_3)
        self.label_9.setObjectName("label_9")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_9)
        self.editError = QtWidgets.QLineEdit(self.tab_3)
        self.editError.setObjectName("editError")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.editError)
        self.label_11 = QtWidgets.QLabel(self.tab_3)
        self.label_11.setObjectName("label_11")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.label_11)
        self.editComTimout = QtWidgets.QLineEdit(self.tab_3)
        self.editComTimout.setObjectName("editComTimout")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.editComTimout)
        spacerItem6 = QtWidgets.QSpacerItem(20, 119, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.formLayout.setItem(9, QtWidgets.QFormLayout.FieldRole, spacerItem6)
        self.editTemp = QtWidgets.QLineEdit(self.tab_3)
        self.editTemp.setObjectName("editTemp")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.editTemp)
        self.label_12 = QtWidgets.QLabel(self.tab_3)
        self.label_12.setObjectName("label_12")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_12)
        self.tabWidget.addTab(self.tab_3, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.buttonConnect = QtWidgets.QPushButton(WBlower)
        self.buttonConnect.setObjectName("buttonConnect")
        self.horizontalLayout.addWidget(self.buttonConnect)
        self.buttonDisconnect = QtWidgets.QPushButton(WBlower)
        self.buttonDisconnect.setObjectName("buttonDisconnect")
        self.horizontalLayout.addWidget(self.buttonDisconnect)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem7)
        self.buttonClose = QtWidgets.QPushButton(WBlower)
        self.buttonClose.setObjectName("buttonClose")
        self.horizontalLayout.addWidget(self.buttonClose)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(WBlower)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(WBlower)

    def retranslateUi(self, WBlower):
        _translate = QtCore.QCoreApplication.translate
        WBlower.setWindowTitle(_translate("WBlower", "Blower status"))
        self.label.setText(_translate("WBlower", "Temperature"))
        self.labelTemp.setText(_translate("WBlower", "<html><head/><body><p>0 &deg;C</p></body></html>"))
        self.label_10.setText(_translate("WBlower", "Current target and ramp"))
        self.labelCurrent.setText(_translate("WBlower", "<html><head/><body><p>0 &deg;C</p></body></html>"))
        self.label_2.setText(_translate("WBlower", "Target temperature"))
        self.label_3.setText(_translate("WBlower", "Temperature ramp (deg/min)"))
        self.buttonRun.setText(_translate("WBlower", "Run"))
        self.buttonToSeq.setText(_translate("WBlower", "To Sequence"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("WBlower", "Control"))
        self.buttonStartPlot.setText(_translate("WBlower", "Start"))
        self.buttonClearPlot.setText(_translate("WBlower", "Clear"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("WBlower", "Plot"))
        self.label_4.setText(_translate("WBlower", "Host"))
        self.label_5.setText(_translate("WBlower", "Session"))
        self.label_7.setText(_translate("WBlower", "Counter"))
        self.label_8.setText(_translate("WBlower", "Ramp command"))
        self.label_9.setText(_translate("WBlower", "Error"))
        self.label_11.setText(_translate("WBlower", "Communication timeout"))
        self.label_12.setText(_translate("WBlower", "Temp command"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("WBlower", "Settings"))
        self.buttonConnect.setText(_translate("WBlower", "Connect"))
        self.buttonDisconnect.setText(_translate("WBlower", "Disconnect"))
        self.buttonClose.setText(_translate("WBlower", "Close"))

from pyqtgraph import PlotWidget
from . import resources_rc
